@@ -5,6 +5,8 @@
 
 #include "test-utils.h"
 
+#ifdef HAVE_PHP_XMLRPC
+
 #ifdef G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 #endif
@@ -180,7 +182,17 @@ do_echo (SoupMessage *msg, GValueArray *params)
 
 	soup_xmlrpc_set_response (msg, G_TYPE_VALUE_ARRAY, out);
 	g_value_array_free (out);
+}
 
+static void
+do_ping (SoupMessage *msg, GValueArray *params)
+{
+	if (params->n_values) {
+		args_error (msg, params, 0);
+		return;
+	}
+
+	soup_xmlrpc_set_response (msg, G_TYPE_STRING, "pong");
 }
 
 static void
@@ -216,6 +228,8 @@ server_callback (SoupServer *server, SoupMessage *msg,
 		do_dateChange (msg, params);
 	else if (!strcmp (method_name, "echo"))
 		do_echo (msg, params);
+	else if (!strcmp (method_name, "ping"))
+		do_ping (msg, params);
 	else {
 		soup_xmlrpc_set_fault (msg, SOUP_XMLRPC_FAULT_SERVER_ERROR_REQUESTED_METHOD_NOT_FOUND,
 				       "Unknown method %s", method_name);
@@ -333,3 +347,13 @@ main (int argc, char **argv)
 		test_cleanup ();
 	return errors != 0;
 }
+
+#else /* HAVE_PHP_XMLRPC */
+
+int
+main (int argc, char **argv)
+{
+	return 77; /* SKIP */
+}
+
+#endif
